<!--
 Copyright European Organization for Nuclear Research (CERN)

 Licensed under the Apache License, Version 2.0 (the "License");
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 http://www.apache.org/licenses/LICENSE-2.0

 Authors:
 - Thomas Beermann, <thomas.beermann@cern.ch>, 2017
-->

$var title: Accounts
$var script: <script src="/static/accounts.js"></script>

<div id="results" class="row">

  <div id="t_data" class="columns panel">
    <h4>Accounts</h4>
    <div id="loader"></div>
    <table id="resulttable" class="compact stripe order-column" style="word-wrap: break-word;">
      <thead><tr><th>Account</th><th>Email</th><th>Type</th></tr></thead>
      <tfoot><tr><th>Account</th><th>Email</th><th>Type</th></tr></tfoot>
    </table>
    <div id="last_update"></div>
  </div>

</div>
<div id="problem"></div>
