
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.17.8.post2',
    'branch_nick': '(HEAD',
    'revision_id': '9f493fd04a26d946181b2379d5e0eb8e53dd1559',
    'revno': 6966
}
